﻿using ProjectContainerShip.DrawningObjects;
using ProjectContainerShip.Generics;
using ProjectContainerShip.MovementStrategy;

namespace ProjectContainerShip
{
    /// <summary>
    /// Форма для работы с набором объектов класса 
    /// </summary>
    public partial class FormShipCollection : Form
    {
        /// <summary>
        /// Набор объектов
        /// </summary>
        private readonly ContainerGenericCollection<DrawningShip,
        DrawningObjectShip> _containerShip;
        /// <summary>
        /// Конструктор
        /// </summary>
        public FormShipCollection()
        {
            InitializeComponent();
            _containerShip = new ContainerGenericCollection<DrawningShip,
        DrawningObjectShip>(pictureBoxCollection.Width, pictureBoxCollection.Height);
        }
        /// <summary>
        /// Добавление объекта в набор
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonAddShip_Click(object sender, EventArgs e)
        {
            FormContainerShip form = new();
            if (form.ShowDialog() == DialogResult.OK)
            {
                if (_containerShip + form.SelectedShip > -1)
                {
                    MessageBox.Show("Объект добавлен");
                    pictureBoxCollection.Image = _containerShip.ShowContainer();
                }
                else
                {
                    MessageBox.Show("Не удалось добавить объект");
                }
            }
        }
        /// <summary>
        /// Удаление объекта из набора
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonRemoveShip_Click(object sender, EventArgs e)
        {
            if (MessageBox.Show("Удалить объект?", "Удаление",
            MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.No)
            {
                return;
            }
            int pos = Convert.ToInt32(maskedTextBoxNumber.Text);
            if (_containerShip - pos != null)
            {
                MessageBox.Show("Объект удален");
                pictureBoxCollection.Image = _containerShip.ShowContainer();
            }
            else
            {
                MessageBox.Show("Не удалось удалить объект");
            }
        }
        /// <summary>
        /// Обновление рисунка по набору
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonRefreshCollection_Click(object sender, EventArgs e)
        {
            pictureBoxCollection.Image = _containerShip.ShowContainer();
        }
    }
}


